@@ -82,6 +82,9 @@ if($rt->type == "Series" || $rt->type == "Courses") {
 	$children = NULL;
 }
 
+//get all subtitles
+$subs = JFolder::files(JPATH_ROOT . DS . $content_folder, '.srt|.SRT');
+
 //get the contributors for the resource
 $sql = "SELECT authorid FROM #__author_assoc "
 	 . "WHERE subtable='resources' "
@@ -91,6 +94,7 @@ $this->database->setQuery( $sql );
 $author_ids = $this->database->loadResultArray();
 
 //get the author names from ids
+$authors = array();
 if ($author_ids && is_array($author_ids))
 {
 	foreach ($author_ids as $ai) 
@@ -137,7 +141,8 @@ if ($author_ids && is_array($author_ids))
 	</dl>
 </div>
 
-<div id="presenter-container">
+<?php $presenationFormat = (isset($presentation->format) && strtoupper($presentation->format) == 'HD') ? 'presentation-hd' : ''; ?>
+<div id="presenter-container" class="<?php echo $presenationFormat; ?>">
 	<div id="presenter-header">
 		<div id="title"><?php echo $rr->title; ?></div>
 		<div id="author"><?php if($authors) { echo "by: " . implode(", ", $authors); } ?></div>
@@ -201,14 +206,31 @@ if ($author_ids && is_array($author_ids))
 						   	<source src="<?php echo $content_folder.DS.$source->source; ?>" type='<?php echo $type; ?>'>
 						<?php endforeach; ?>
 						<a href="<?php echo $content_folder.DS.$presentation->media[0]->source; ?>" id="flowplayer"></a>
+							
+						<?php foreach($subs as $sub) : ?>
+							<?php $info2 = pathinfo($sub); ?>
+							<div data-type="subtitle" data-lang="<?php echo $info2['filename']; ?>" data-src="<?php echo $content_folder . DS . $sub; ?>"></div>
+						<?php endforeach; ?>
+						
 					</video>
 				<?php else : ?>
 					<audio id="player" preload="auto" controls="controls">          
 						<?php foreach($presentation->media as $source): ?>
-							<source src="<?php echo $content_folder.DS.$source->source; ?>" />
+							<?php
+								switch( $source->type )
+								{
+									case 'mp3':		$type = 'audio/mp3';	break;
+									case 'ogg':		$type = 'audio/ogg';	break;
+								}
+							?>
+							<source src="<?php echo $content_folder.DS.$source->source; ?>" type="<?php echo $type; ?>" />
 						<?php endforeach; ?>
 						<a href="<?php echo $content_folder.DS.$presentation->media[0]->source; ?>" id="flowplayer" duration="<?php if($presentation->duration) { echo $presentation->duration; } ?>"></a>
 					</audio>
+					
+					<?php if($presentation->placeholder) : ?>
+						<img src="<?php echo $content_folder.DS.$presentation->placeholder; ?>" title="" id="placeholder" />
+					<?php endif; ?>
 				<?php endif; ?>
 			</div>
 			<div id="list">
