@@ -31,6 +31,12 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Tool_Version');
+ximport('Hubzero_Tool');
+ximport('Hubzero_Group');
+ximport('Hubzero_Trac_Project');
+ximport('Hubzero_Controller');
+
 include_once(JPATH_ROOT . DS . 'components' . DS . 'com_tools' . DS . 'helpers' . DS . 'helper.php');
 include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_tools' . DS . 'tables' . DS . 'tool.php');
 include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_tools' . DS . 'tables' . DS . 'version.php');
@@ -40,11 +46,11 @@ include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_r
 /**
  * Controller class for contributing a tool
  */
-class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
+class ToolsControllerScreenshots extends Hubzero_Controller
 {
 	/**
 	 * Determines task being called and attempts to execute it
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function execute()
@@ -52,7 +58,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$this->_authorize();
 
 		// Load the com_resources component config
-		$rconfig = JComponentHelper::getParams('com_resources');
+		$rconfig =& JComponentHelper::getParams('com_resources');
 		$this->rconfig = $rconfig;
 
 		parent::execute();
@@ -60,7 +66,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Reorder screenshots
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function reorderTask()
@@ -69,9 +75,9 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$pid = JRequest::getInt('pid', 0);
 		$version = JRequest::getVar('version', 'dev');
 
-		if (!$pid)
+		if (!$pid) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_ID'));
+			$this->setError(JText::_('CONTRIBUTE_NO_ID'));
 			$this->displayTask($pid, $version);
 			return;
 		}
@@ -81,9 +87,9 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$this->_toolid = $obj->getToolIdFromResource($pid);
 
 		// make sure user is authorized to go further
-		if (!$this->check_access($this->_toolid))
+		if (!$this->check_access($this->_toolid)) 
 		{
-			JError::raiseError(403, JText::_('COM_TOOLS_ALERTNOTAUTH'));
+			JError::raiseError(403, JText::_('ALERTNOTAUTH'));
 			return;
 		}
 
@@ -91,9 +97,9 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$objV = new ToolVersion($this->database);
 		$vid = $objV->getVersionIdFromResource($pid, $version);
 
-		if ($vid == NULL)
+		if ($vid == NULL) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_VERSION_ID_NOT_FOUND'));
+			$this->setError(JText::_('CONTRIBUTE_VERSION_ID_NOT_FOUND'));
 			$this->displayTask($pid, $version);
 			return;
 		}
@@ -113,19 +119,19 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$shot2 = $ss->getScreenshot($file_toleft, $pid, $vid);
 
 		// Do we have information stored?
-		if ($shot1)
+		if ($shot1) 
 		{
 			$ss->saveScreenshot($file_toright, $pid, $vid, $neworder_toright);
 		}
-		else
+		else 
 		{
 			$ss->saveScreenshot($file_toright, $pid, $vid, $neworder_toright, true);
 		}
-		if ($shot1)
+		if ($shot1) 
 		{
 			$ss->saveScreenshot($file_toleft, $pid, $vid, $neworder_toleft);
 		}
-		else
+		else 
 		{
 			$ss->saveScreenshot($file_toleft, $pid, $vid, $neworder_toleft, true);
 		}
@@ -138,7 +144,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Edit a screenshot
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function editTask()
@@ -146,18 +152,18 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		// Incoming parent ID
 		$pid = JRequest::getInt('pid', 0);
 		$version = JRequest::getVar('version', 'dev');
-		if (!$pid)
+		if (!$pid) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_ID'));
+			$this->setError(JText::_('CONTRIBUTE_NO_ID'));
 			$this->displayTask($pid, $version);
 			return;
 		}
 
 		// Incoming child ID
 		$this->view->file = JRequest::getVar('filename', '');
-		if (!$this->view->file)
+		if (!$this->view->file) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_CHILD_ID'));
+			$this->setError(JText::_('CONTRIBUTE_NO_CHILD_ID'));
 			$this->displayTask($pid, $version);
 			return;
 		}
@@ -166,13 +172,13 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$row = new ResourcesResource($this->database);
 		$row->load($pid);
 
-		// Get version id
+		// Get version id	
 		$objV = new ToolVersion($this->database);
 		$vid = $objV->getVersionIdFromResource($pid, $version);
 
-		if ($vid == NULL)
+		if ($vid == NULL) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_VERSION_ID_NOT_FOUND'));
+			$this->setError(JText::_('CONTRIBUTE_VERSION_ID_NOT_FOUND'));
 			$this->displayTask($pid, $version);
 			return;
 		}
@@ -188,18 +194,18 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$this->view->shot = $ss->getScreenshot($this->view->file, $pid, $vid);
 
 		// Get the app
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 
 		// Set the page title
-		$this->view->title = JText::_(strtoupper($this->_name)) . ': ' . JText::_('COM_TOOLS_TASK_EDIT_SS');
-		$document = JFactory::getDocument();
+		$this->view->title = JText::_(strtoupper($this->_name)) . ': ' . JText::_('TASK_EDIT_SS');
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->view->title);
 
 		$this->view->pid = $pid;
 		$this->view->version = $version;
 		$this->view->vid = $vid;
 
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -213,7 +219,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Save changes to a screenshot
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function saveTask()
@@ -222,9 +228,9 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$pid = JRequest::getInt('pid', 0);
 		$version = JRequest::getVar('version', 'dev');
 		$vid = JRequest::getInt('vid', 0);
-		if (!$pid)
+		if (!$pid) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_ID'));
+			$this->setError(JText::_('CONTRIBUTE_NO_ID'));
 			$this->displayTask($pid, $version);
 			return;
 		}
@@ -238,12 +244,12 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$shot = $ss->getScreenshot($file, $pid, $vid);
 		$files = $ss->getFiles($pid, $vid);
 
-		if ($shot)
+		if ($shot) 
 		{
 			// update entry
 			$ss->loadFromFilename($file, $pid, $vid);
-		}
-		else
+		} 
+		else 
 		{
 			// make new entry
 			$ss->versionid = $vid;
@@ -254,7 +260,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		}
 		$ss->title = preg_replace('/"((.)*?)"/i', "&#147;\\1&#148;", $title);
 
-		if (!$ss->store())
+		if (!$ss->store()) 
 		{
 			$this->setError($ss->getError());
 		}
@@ -265,7 +271,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Delete a screenshot
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function deleteTask()
@@ -273,18 +279,18 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		// Incoming parent ID
 		$pid = JRequest::getInt('pid', 0);
 		$version = JRequest::getVar('version', 'dev');
-		if (!$pid)
+		if (!$pid) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_ID'));
+			$this->setError(JText::_('CONTRIBUTE_NO_ID'));
 			$this->displayTask($pid, $version);
 			return;
 		}
 
 		// Incoming child ID
 		$file = JRequest::getVar('filename', '');
-		if (!$file)
+		if (!$file) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_CHILD_ID'));
+			$this->setError(JText::_('CONTRIBUTE_NO_CHILD_ID'));
 			$this->displayTask($pid, $version);
 			return;
 		}
@@ -300,9 +306,9 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$objV = new ToolVersion($this->database);
 		$vid = $objV->getVersionIdFromResource($pid, $version);
 
-		if ($vid == NULL)
+		if ($vid == NULL) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_VERSION_ID_NOT_FOUND'));
+			$this->setError(JText::_('CONTRIBUTE_VERSION_ID_NOT_FOUND'));
 			$this->displayTask($pid, $version);
 			return;
 		}
@@ -315,27 +321,27 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$path = $this->_buildUploadPath($listdir, '');
 
 		// Check if the folder even exists
-		if (!is_dir($path) or !$path)
+		if (!is_dir($path) or !$path) 
 		{
-			$this->setError(JText::_('COM_TOOLS_DIRECTORY_NOT_FOUND'));
+			$this->setError(JText::_('DIRECTORY_NOT_FOUND'));
 			$this->displayTask($pid, $version);
 			return;
-		}
-		else
+		} 
+		else 
 		{
-			if (!JFile::exists($path . DS . $file))
+			if (!JFile::exists($path . DS . $file)) 
 			{
 				$this->displayTask($pid, $version);
 				return;
 			}
 
-			if (!JFile::delete($path . DS . $file))
+			if (!JFile::delete($path . DS . $file)) 
 			{
-				$this->setError(JText::_('COM_TOOLS_UNABLE_TO_DELETE_FILE'));
+				$this->setError(JText::_('UNABLE_TO_DELETE_FILE'));
 				$this->displayTask($pid, $version);
 				return;
 			}
-			else
+			else 
 			{
 				// Delete thumbnail
 				$tn = ResourcesHtml::thumbnail($file);
@@ -355,16 +361,16 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Upload a screenshot
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function uploadTask()
 	{
 		// Incoming
 		$pid = JRequest::getInt('pid', 0);
-		if (!$pid)
+		if (!$pid) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_ID'));
+			$this->setError(JText::_('CONTRIBUTE_NO_ID'));
 			$this->displayTask($pid, $version);
 			return;
 		}
@@ -373,7 +379,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$title = preg_replace('/\s+/', ' ',JRequest::getVar('title', ''));
 		$allowed = array('.gif','.jpg','.png','.bmp');
 		$changing_version = JRequest::getInt('changing_version', 0);
-		if ($changing_version)
+		if ($changing_version) 
 		{
 			// reload screen
 			$this->displayTask($pid, $version);
@@ -386,9 +392,9 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 		// Incoming file
 		$file = JRequest::getVar('upload', '', 'files', 'array');
-		if (!$file['name'])
+		if (!$file['name']) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_FILE'));
+			$this->setError(JText::_('CONTRIBUTE_NO_FILE'));
 			$this->displayTask($pid, $version);
 			return;
 		}
@@ -402,20 +408,20 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$file_ext      = substr($file['name'], strripos($file['name'], '.'));
 
 		// Make sure we have an allowed format
-		if (!in_array(strtolower($file_ext), $allowed))
+		if (!in_array(strtolower($file_ext), $allowed)) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_WRONG_FILE_FORMAT'));
+			$this->setError(JText::_('CONTRIBUTE_WRONG_FILE_FORMAT'));
 			$this->displayTask($pid, $version);
 			return;
 		}
 
-		// Get version id
+		// Get version id	
 		$objV = new ToolVersion($this->database);
 		$vid = $objV->getVersionIdFromResource($pid, $version);
 
-		if ($vid == NULL)
+		if ($vid == NULL) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_VERSION_ID_NOT_FOUND'));
+			$this->setError(JText::_('CONTRIBUTE_VERSION_ID_NOT_FOUND'));
 			$this->displayTask($pid, $version);
 			return;
 		}
@@ -425,12 +431,12 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 		// Check if file with the same name already exists
 		$files = $row->getFiles($pid, $vid);
-		if (count($files) > 0)
+		if (count($files) > 0) 
 		{
 			$files = ToolsHelperUtils::transform($files, 'filename');
-			foreach ($files as $f)
+			foreach ($files as $f) 
 			{
-				if ($f == $file['name'])
+				if ($f == $file['name']) 
 				{
 					// append extra characters in the end
 					$file['name'] = $file_basename . '_' . time() . $file_ext;
@@ -447,7 +453,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$row->resourceid = $pid;
 
 		// Check content
-		if (!$row->check())
+		if (!$row->check()) 
 		{
 			$this->setError($row->getError());
 			$this->displayTask($pid, $version);
@@ -461,33 +467,33 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$path = $this->_buildUploadPath($listdir, '');
 
 		// Make sure the upload path exist
-		if (!is_dir($path))
+		if (!is_dir($path)) 
 		{
 			jimport('joomla.filesystem.folder');
-			if (!JFolder::create($path))
+			if (!JFolder::create($path, 0777)) 
 			{
-				$this->setError(JText::_('COM_TOOLS_UNABLE_TO_CREATE_UPLOAD_PATH') . $path);
+				$this->setError(JText::_('UNABLE_TO_CREATE_UPLOAD_PATH') . $path);
 				$this->displayTask($pid, $version);
 				return;
 			}
 		}
 
 		// Perform the upload
-		if (!JFile::upload($file['tmp_name'], $path . DS . $file['name']))
+		if (!JFile::upload($file['tmp_name'], $path . DS . $file['name'])) 
 		{
-			$this->setError(JText::_('COM_TOOLS_ERROR_UPLOADING'));
+			$this->setError(JText::_('ERROR_UPLOADING'));
 		}
-		else
+		else 
 		{
 			// Store new content
-			if (!$row->store())
+			if (!$row->store()) 
 			{
 				$this->setError($row->getError());
 				$this->displayTask($pid, $version);
 				return;
 			}
 
-			if (!$row->id)
+			if (!$row->id) 
 			{
 				$row->id = $row->insertid();
 			}
@@ -497,18 +503,18 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 			$ss_width  = (intval($this->config->get('screenshot_maxwidth', 91)) > 80)  ? intval($this->config->get('screenshot_maxwidth', 91))  : 91;
 
 			$tn = ResourcesHtml::thumbnail($file['name']);
-			if ($file_ext != '.swf')
+			if ($file_ext != '.swf') 
 			{
 				$this->_createThumb($path . DS . $file['name'], $ss_width, $ss_height, $path, $tn);
 			}
-			else
+			else 
 			{
 				//$this->_createAnimThumb($path . DS . $file['name'], $ss_width, $ss_height, $path, $tn);
 			}
 		}
 
 		// Store new content
-		if (!$row->store())
+		if (!$row->store()) 
 		{
 			$this->setError($row->getError());
 			$this->displayTask($pid, $version);
@@ -523,7 +529,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Create a thumbnail for an animation
-	 *
+	 * 
 	 * @param      string  $tmpname   Uploaded file name
 	 * @param      integer $maxwidth  Max image width
 	 * @param      integer $maxheight Max image height
@@ -545,13 +551,13 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 		$im = imagecreate($av, $ah);
 		$im = imagecreatetruecolor($av, $ah);
-		if (imagecopyresampled($im, $imorig, 0, 0, 0, 0, $av, $ah, $x, $y))
+		if (imagecopyresampled($im, $imorig, 0, 0, 0, 0, $av, $ah, $x, $y)) 
 		{
-			if (imagegif($im, $save_dir . $save_name))
+			if (imagegif($im, $save_dir . $save_name)) 
 			{
 				return true;
 			}
-			else
+			else 
 			{
 				return false;
 			}
@@ -560,7 +566,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Create a thumbnail from a picture
-	 *
+	 * 
 	 * @param      string  $tmpname   Uploaded file name
 	 * @param      integer $maxwidth  Max image width
 	 * @param      integer $maxheight Max image height
@@ -600,13 +606,13 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 		$im = imagecreate($av, $ah);
 		$im = imagecreatetruecolor($av, $ah);
-		if (imagecopyresampled($im, $imorig, 0, 0, 0, 0, $av, $ah, $x, $y))
+		if (imagecopyresampled($im, $imorig, 0, 0, 0, 0, $av, $ah, $x, $y)) 
 		{
-			if (imagegif($im, $save_dir . $save_name))
+			if (imagegif($im, $save_dir . $save_name)) 
 			{
 				return true;
 			}
-			else
+			else 
 			{
 				return false;
 			}
@@ -615,7 +621,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Copy files
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function copyTask()
@@ -636,15 +642,15 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$obj = new Tool($this->database);
 		$toolid = $obj->getToolIdFromResource($rid);
 
-		if ($from == 0 or $to == 0 or $rid == 0)
+		if ($from == 0 or $to == 0 or $rid == 0) 
 		{
-			JError::raiseError(500, JText::_('COM_TOOLS_CONTRIBUTE_NO_ID'));
+			JError::raiseError(500, JText::_('Missing ids'));
 			return;
 		}
 
-		if ($toolid && $this->_checkAccess($toolid))
+		if ($toolid && $this->_checkAccess($toolid)) 
 		{
-			if ($this->transfer($from, $to, $rid))
+			if ($this->transfer($from, $to, $rid)) 
 			{
 				// Push through to the screenshot view
 				$this->displayTask($rid, $version);
@@ -654,7 +660,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Move files
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function moveTask()
@@ -667,15 +673,15 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		// get admin priviliges
 		$this->_authorize();
 
-		if ($this->config->get('access-admin-component') or $this->_task == 'copy')
+		if ($this->config->get('access-admin-component') or $this->_task == 'copy') 
 		{
-			if ($from == 0 or $to == 0 or $rid == 0)
+			if ($from == 0 or $to == 0 or $rid == 0) 
 			{
-				JError::raiseError(500, JText::_('COM_TOOLS_CONTRIBUTE_NO_ID'));
+				JError::raiseError(500, JText::_('Missing ids'));
 				return;
 			}
 
-			if ($this->transfer($from, $to, $rid))
+			if ($this->transfer($from, $to, $rid)) 
 			{
 				if ($this->_task == 'copy')
 				{
@@ -683,17 +689,17 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 					// Push through to the screenshot view
 					$this->displayTask($rid, $version);
 				}
-				else
+				else 
 				{
-					echo JText::_('COM_TOOLS_SUCCESS');
+					echo JText::_('Success!');
 				}
 			}
-			else if ($this->_task != 'copy')
+			else if ($this->_task != 'copy') 
 			{
-				$this->setError(JText::_('COM_TOOLS_ERROR_COPYING_FILES'));
+				$this->setError(JText::_('Didn\'t work. There were some problems...'));
 			}
 		}
-		else
+		else 
 		{
 			$this->setRedirect(
 				JRoute::_('index.php?option=' . $this->_option)
@@ -703,7 +709,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Transfer files from one version to another
-	 *
+	 * 
 	 * @param      string  $sourceid Source version ID
 	 * @param      string  $destid   Destination version ID
 	 * @param      integer $rid      Resource ID
@@ -711,8 +717,8 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 	 */
 	public function transfer($sourceid, $destid, $rid)
 	{
-		$xlog = JFactory::getLogger();
-		$xlog->debug(__FUNCTION__ . '()');
+		$xlog =& Hubzero_Factory::getLogger();
+		$xlog->logDebug(__FUNCTION__ . '()');
 
 		// Get resource information
 		$resource = new ResourcesResource($this->database);
@@ -734,45 +740,45 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		jimport('joomla.filesystem.folder');
 
 		// Make sure the path exist
-		if (!is_dir($src))
+		if (!is_dir($src)) 
 		{
-			if (!JFolder::create($src))
+			if (!JFolder::create($src, 0777)) 
 			{
-				$this->setError(JText::_('COM_TOOLS_UNABLE_TO_CREATE_UPLOAD_PATH'));
+				$this->setError(JText::_('UNABLE_TO_CREATE_UPLOAD_PATH'));
 				return false;
 			}
 		}
-		$xlog->debug(__FUNCTION__ . "() $src");
+		$xlog->logDebug(__FUNCTION__ . "() $src");
 
 		// do we have files to transfer?
 		$files = JFolder::files($src, '.', false, true, array());
-		$xlog->debug(__FUNCTION__ . "() $files");
-		if (!empty($files))
+		$xlog->logDebug(__FUNCTION__ . "() $files");
+		if (!empty($files)) 
 		{
 			// Copy directory
-			$xlog->debug(__FUNCTION__ . "() copying $src to $dest");
-			if (!JFolder::copy($src, $dest, '', true))
+			$xlog->logDebug(__FUNCTION__ . "() copying $src to $dest");
+			if (!JFolder::copy($src, $dest, '', true)) 
 			{
 				return false;
 			}
-			else
+			else 
 			{
 				// Update screenshot information for this resource
 				$ss->updateFiles($rid, $sourceid, $destid, $copy=1);
 
-				$xlog->debug(__FUNCTION__ . '() updated files');
+				$xlog->logDebug(__FUNCTION__ . '() updated files');
 				return true;
 			}
 		}
 
-		$xlog->debug(__FUNCTION__ . '() done');
+		$xlog->logDebug(__FUNCTION__ . '() done');
 
 		return true;
 	}
 
 	/**
 	 * Display a list of screenshots for this entry
-	 *
+	 * 
 	 * @param      integer $rid     Resource ID
 	 * @param      string  $version Tool version
 	 * @return     void
@@ -780,28 +786,28 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 	public function displayTask($rid=NULL, $version=NULL)
 	{
 		$this->view->setLayout('display');
-
+		
 		// Incoming
-		if (!$rid)
+		if (!$rid) 
 		{
 			$rid = JRequest::getInt('rid', 0);
 		}
-		if (!$version)
+		if (!$version) 
 		{
 			$version = JRequest::getVar('version', 'dev');
 		}
 
 		// Ensure we have an ID to work with
-		if (!$rid)
+		if (!$rid) 
 		{
-			JError::raiseError(500, JText::_('COM_TOOLS_CONTRIBUTE_NO_ID'));
+			JError::raiseError(500, JText::_('CONTRIBUTE_NO_ID'));
 			return;
 		}
 		// Get resource information
 		$resource = new ResourcesResource($this->database);
 		$resource->load($rid);
 
-		// Get version id
+		// Get version id	
 		$objV = new ToolVersion($this->database);
 		$vid = $objV->getVersionIdFromResource($rid, $version);
 
@@ -818,18 +824,20 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$path = ResourcesHtml::build_path($resource->created, $rid, '');
 		$this->view->upath = JPATH_ROOT . DS . trim($this->rconfig->get('uploadpath'), DS) . $path;
 		$this->view->wpath = DS . trim($this->rconfig->get('uploadpath'), DS) . $path;
-		if ($vid)
+		if ($vid) 
 		{
 			$this->view->upath .= DS . $vid;
 			$this->view->wpath .= DS . $vid;
 		}
 
 		// get config
-		$this->view->cparams = JComponentHelper::getParams('com_resources');
+		$this->view->cparams =& JComponentHelper::getParams('com_resources');
 		$this->view->version = $version;
 		$this->view->rid = $rid;
 
-		if ($this->getError())
+		$this->_getStyles($this->_option, 'assets/css/component.css');
+
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -843,23 +851,23 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Construct a path to upload files to
-	 *
+	 * 
 	 * @param      string $listdir Base directory
 	 * @param      string $subdir  Sub-directory
-	 * @return     string
+	 * @return     string 
 	 */
 	private function _buildUploadPath($listdir, $subdir='')
 	{
-		if ($subdir)
+		if ($subdir) 
 		{
 			$subdir = DS . trim($subdir, DS);
 		}
 
 		// Get the configured upload path
-		$rconfig = JComponentHelper::getParams('com_resources');
+		$rconfig =& JComponentHelper::getParams('com_resources');
 
 		$base_path = $rconfig->get('uploadpath');
-		if ($base_path)
+		if ($base_path) 
 		{
 			// Make sure the path doesn't end with a slash
 			$base_path = DS . trim($base_path, DS);
@@ -867,13 +875,13 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 		// Make sure the path doesn't end with a slash
 		$listdir = DS . trim($listdir, DS);
-
+		
 		// Does the beginning of the $listdir match the config path?
-		if (substr($listdir, 0, strlen($base_path)) == $base_path)
+		if (substr($listdir, 0, strlen($base_path)) == $base_path) 
 		{
 			// Yes - ... this really shouldn't happen
-		}
-		else
+		} 
+		else 
 		{
 			// No - append it
 			$listdir = $base_path . $listdir;
@@ -885,7 +893,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Get the resource child type from the file extension
-	 *
+	 * 
 	 * @param      string $filename File to check
 	 * @return     integer Numerical file type
 	 */
@@ -914,7 +922,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Check if the current user has access to this tool
-	 *
+	 * 
 	 * @param      unknown $toolid       Tool ID
 	 * @param      integer $allowAdmins  Allow admins access?
 	 * @param      boolean $allowAuthors Allow authors access?
@@ -926,17 +934,17 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		$obj = new Tool($this->database);
 
 		// allow to view if admin
-		if ($this->config->get('access-manage-component') && $allowAdmins)
+		if ($this->config->get('access-manage-component') && $allowAdmins) 
 		{
 			return true;
 		}
 
 		// check if user in tool dev team
-		if ($developers = $obj->getToolDevelopers($toolid))
+		if ($developers = $obj->getToolDevelopers($toolid)) 
 		{
-			foreach ($developers as $dv)
+			foreach ($developers as $dv) 
 			{
-				if ($dv->uidNumber == $this->juser->get('id'))
+				if ($dv->uidNumber == $this->juser->get('id')) 
 				{
 					return true;
 				}
@@ -944,7 +952,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 		}
 
 		// allow access to tool authors
-		if ($allowAuthors)
+		if ($allowAuthors) 
 		{
 			// Nothing here?
 		}
@@ -954,7 +962,7 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 
 	/**
 	 * Authorization checks
-	 *
+	 * 
 	 * @param      string $assetType Asset type
 	 * @param      string $assetId   Asset id to check against
 	 * @return     void
@@ -962,23 +970,24 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 	protected function _authorize($assetType='component', $assetId=null)
 	{
 		$this->config->set('access-view-' . $assetType, true);
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
 			return;
 		}
 
 		// if no admin group is defined, allow superadmin to act as admin
 		// otherwise superadmins can only act if they are also a member of the component admin group
-		if (($admingroup = trim($this->config->get('admingroup', ''))))
+		if (($admingroup = trim($this->config->get('admingroup', '')))) 
 		{
+			ximport('Hubzero_User_Helper');
 			// Check if they're a member of admin group
-			$ugs = \Hubzero\User\Helper::getGroups($this->juser->get('id'));
-			if ($ugs && count($ugs) > 0)
+			$ugs = Hubzero_User_Helper::getGroups($this->juser->get('id'));
+			if ($ugs && count($ugs) > 0) 
 			{
 				$admingroup = strtolower($admingroup);
 				foreach ($ugs as $ug)
 				{
-					if (strtolower($ug->cn) == $admingroup)
+					if (strtolower($ug->cn) == $admingroup) 
 					{
 						$this->config->set('access-manage-' . $assetType, true);
 						$this->config->set('access-admin-' . $assetType, true);
@@ -989,30 +998,44 @@ class ToolsControllerScreenshots extends \Hubzero\Component\SiteController
 				}
 			}
 		}
-		else
+		else 
 		{
-			$asset  = $this->_option;
-			if ($assetId)
+			if (version_compare(JVERSION, '1.6', 'ge'))
 			{
-				$asset .= ($assetType != 'component') ? '.' . $assetType : '';
-				$asset .= ($assetId) ? '.' . $assetId : '';
-			}
+				$asset  = $this->_option;
+				if ($assetId)
+				{
+					$asset .= ($assetType != 'component') ? '.' . $assetType : '';
+					$asset .= ($assetId) ? '.' . $assetId : '';
+				}
 
-			$at = '';
-			if ($assetType != 'component')
+				$at = '';
+				if ($assetType != 'component')
+				{
+					$at .= '.' . $assetType;
+				}
+
+				// Admin
+				$this->config->set('access-admin-' . $assetType, $this->juser->authorise('core.admin', $asset));
+				$this->config->set('access-manage-' . $assetType, $this->juser->authorise('core.manage', $asset));
+				// Permissions
+				$this->config->set('access-create-' . $assetType, $this->juser->authorise('core.create' . $at, $asset));
+				$this->config->set('access-delete-' . $assetType, $this->juser->authorise('core.delete' . $at, $asset));
+				$this->config->set('access-edit-' . $assetType, $this->juser->authorise('core.edit' . $at, $asset));
+				$this->config->set('access-edit-state-' . $assetType, $this->juser->authorise('core.edit.state' . $at, $asset));
+				$this->config->set('access-edit-own-' . $assetType, $this->juser->authorise('core.edit.own' . $at, $asset));
+			}
+			else 
 			{
-				$at .= '.' . $assetType;
+				if ($this->juser->authorize($this->_option, 'manage'))
+				{
+					$this->config->set('access-manage-' . $assetType, true);
+					$this->config->set('access-admin-' . $assetType, true);
+					$this->config->set('access-create-' . $assetType, true);
+					$this->config->set('access-delete-' . $assetType, true);
+					$this->config->set('access-edit-' . $assetType, true);
+				}
 			}
-
-			// Admin
-			$this->config->set('access-admin-' . $assetType, $this->juser->authorise('core.admin', $asset));
-			$this->config->set('access-manage-' . $assetType, $this->juser->authorise('core.manage', $asset));
-			// Permissions
-			$this->config->set('access-create-' . $assetType, $this->juser->authorise('core.create' . $at, $asset));
-			$this->config->set('access-delete-' . $assetType, $this->juser->authorise('core.delete' . $at, $asset));
-			$this->config->set('access-edit-' . $assetType, $this->juser->authorise('core.edit' . $at, $asset));
-			$this->config->set('access-edit-state-' . $assetType, $this->juser->authorise('core.edit.state' . $at, $asset));
-			$this->config->set('access-edit-own-' . $assetType, $this->juser->authorise('core.edit.own' . $at, $asset));
 		}
 	}
 }
