@@ -31,8 +31,8 @@ class JHTMLForm
 	 * @return	void
 	 * @since	1.5
 	 */
-	function token()
+	static function token()
 	{
 		return '<input type="hidden" name="'.JUtility::getToken().'" value="1" />';
 	}
-}
\ No newline at end of file
+}
