@@ -31,12 +31,12 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$base = 'index.php?option=' . $this->option . '&cn=' . $this->group->get('cn') . '&active=' . $this->name;
+$base = 'index.php?option=' . $this->option . '&gid=' . $this->group->get('cn') . '&active=' . $this->name;
 
 $identifier = $this->post->item()->get('title');
 if (!$identifier)
 {
-	$identifier = $this->post->item()->description('clean');
+	$identifier = $this->post->item()->get('description');
 	if (!$identifier)
 	{
 		$identifier = '#' . $this->post->item()->get('id');
@@ -50,25 +50,23 @@ if (!$identifier)
 		<fieldset>
 			<legend><?php echo JText::_('PLG_GROUPS_COLLECTIONS_DELETE_HEADER'); ?></legend>
 
-			<p class="warning"><?php echo JText::sprintf('PLG_GROUPS_COLLECTIONS_DELETE_WARNING', $this->escape(stripslashes($identifier))); ?></p>
+			<p class="warning"><?php echo JText::_('PLG_GROUPS_COLLECTIONS_DELETE_WARNING'); ?></p>
 
 			<label>
-				<input type="checkbox" class="option" name="confirmdel" value="1" />
+				<input type="checkbox" class="option" name="confirmdel" value="1" /> 
 				<?php echo JText::_('PLG_GROUPS_COLLECTIONS_DELETE_CONFIRM'); ?>
 			</label>
 		</fieldset>
 		<div class="clear"></div>
 
-		<input type="hidden" name="cn" value="<?php echo $this->escape($this->group->get('cn')); ?>" />
+		<input type="hidden" name="gid" value="<?php echo $this->group->get('cn'); ?>" />
 		<input type="hidden" name="process" value="1" />
 		<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
 		<input type="hidden" name="active" value="<?php echo $this->name; ?>" />
-		<input type="hidden" name="action" value="delete" />
-		<input type="hidden" name="post" value="<?php echo $this->escape($this->post->get('id')); ?>" />
+		<input type="hidden" name="task" value="delete" />
+		<input type="hidden" name="post" value="<?php echo $this->post->get('id'); ?>" />
 		<input type="hidden" name="no_html" value="<?php echo $this->no_html; ?>" />
 
-		<?php echo JHTML::_('form.token'); ?>
-
 		<p class="submit">
 			<input type="submit" value="<?php echo JText::_('PLG_GROUPS_COLLECTIONS_DELETE'); ?>" />
 <?php if (!$this->no_html) { ?>
