@@ -128,8 +128,8 @@ class FileMacro extends WikiMacro
 			$this->config->set('filepath', $this->filepath);
 		}
 		$imgs = explode(',', $this->config->get('img_ext', 'jpg, jpeg, jpe, gif, png'));
-		array_map('trim', $imgs);
-		array_map('strtolower', $imgs);
+		$imgs = array_map('trim', $imgs);
+		$imgs = array_map('strtolower', $imgs);
 		$this->imgs = $imgs;
 
 		$ret = false;
@@ -170,7 +170,7 @@ class FileMacro extends WikiMacro
 				$attr['created_by'] = $attach->created_by;
 			}
 
-			$attr['desc'] = (isset($attr['desc'])) ? $attr['desc'] : ''; //$file;
+			$attr['desc'] = (isset($attr['desc'])) ? $attr['desc'] : $file;
 
 			$ret = true;
 		} 
