@@ -32,77 +32,81 @@
 defined('_JEXEC') or die('Restricted access');
 
 /**
- * Table class for resource sponsor
+ * Short description for 'ResourcesType'
+ * 
+ * Long description (if any) ...
  */
 class ResourcesSponsor extends JTable
 {
 	/**
 	 * Description for 'id'
-	 *
+	 * 
 	 * @var unknown
 	 */
 	var $id       		= NULL;  // @var int(11) Primary key
-
+	
 	/**
 	 * Description for 'alias'
-	 *
+	 * 
 	 * @var unknown
 	 */
 	var $alias	  		= NULL;	 // @var varchar(100)
 
 	/**
 	 * Description for 'type'
-	 *
+	 * 
 	 * @var unknown
 	 */
 	var $title     		= NULL;  // @var varchar(250)
 
 	/**
 	 * Description for 'state'
-	 *
+	 * 
 	 * @var unknown
 	 */
 	var $state 		= NULL;  // @var int(3)
 
 	/**
 	 * Description for 'params'
-	 *
+	 * 
 	 * @var unknown
 	 */
 	var $created = NULL;  // @var text
-
+	
 	/**
 	 * Description for 'params'
-	 *
+	 * 
 	 * @var unknown
 	 */
 	var $created_by = NULL;  // @var text
-
+	
 	/**
 	 * Description for 'params'
-	 *
+	 * 
 	 * @var unknown
 	 */
 	var $modified = NULL;  // @var text
-
+	
 	/**
 	 * Description for 'params'
-	 *
+	 * 
 	 * @var unknown
 	 */
 	var $modified_by = NULL;  // @var text
 
 	/**
 	 * Description for 'description'
-	 *
+	 * 
 	 * @var unknown
 	 */
 	var $description 	= NULL;  // @var text
 
 	/**
-	 * Constructor
-	 *
-	 * @param      object &$db JDatabase
+	 * Short description for '__construct'
+	 * 
+	 * Long description (if any) ...
+	 * 
+	 * @param      unknown &$db Parameter description (if any) ...
 	 * @return     void
 	 */
 	public function __construct(&$db)
@@ -111,68 +115,72 @@ class ResourcesSponsor extends JTable
 	}
 
 	/**
-	 * Data validation
-	 *
-	 * @return     boolean True on success, False on error
+	 * Short description for 'check'
+	 * 
+	 * Long description (if any) ...
+	 * 
+	 * @return     boolean Return description (if any) ...
 	 */
 	public function check()
 	{
 		$this->title = trim($this->title);
 		$this->description = trim($this->description);
-
-		if (!$this->title)
+		
+		if (!$this->title) 
 		{
-			$this->setError(JText::_('PLG_RESOURCES_SPONSORS_MISSING_TITLE'));
+			$this->setError(JText::_('Please provide a title.'));
 			return false;
 		}
-
+		
 		if (!$this->alias)
 		{
 			$this->alias = strtolower($this->title);
 		}
 		$this->alias = preg_replace("/[^a-zA-Z0-9\-]/", '', $this->alias);
-
-		$juser = JFactory::getUser();
-		if (!$this->id)
+		
+		$juser =& JFactory::getUser();
+		if (!$this->id) 
 		{
-			$this->created = JFactory::getDate()->toSql();
+			$this->created = date('Y-m-d H:i:s', time());  // use gmdate() ?
 			$this->created_by = $juser->get('id');
-		}
-		else
+		} 
+		else 
 		{
-			$this->modified = JFactory::getDate()->toSql();
+			$this->modified = date('Y-m-d H:i:s', time());  // use gmdate() ?
 			$this->modified_by = $juser->get('id');
 		}
-
+		
 		return true;
 	}
-
+	
 	/**
-	 * Load a record by the alias
-	 *
-	 * @param      string  $oid Alias
-	 * @return     boolean True on success, False on error
+	 * Short description for 'loadAlias'
+	 * 
+	 * Long description (if any) ...
+	 * 
+	 * @param      unknown $oid Parameter description (if any) ...
+	 * @return     boolean Return description (if any) ...
 	 */
-	public function load($keys = NULL, $reset = true)
+	public function load($oid=NULL)
 	{
-		if ($keys === NULL)
+		if ($oid === NULL) 
 		{
 			return false;
 		}
-
-		if (is_numeric($keys))
+		
+		if (is_numeric($oid))
 		{
-			return parent::load($keys);
+			return parent::load($oid);
 		}
-
-		$oid = trim($keys);
-
-		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE alias=" . $this->_db->Quote($oid));
-		if ($result = $this->_db->loadAssoc())
+		
+		$oid = trim($oid);
+		
+		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE alias='$oid'");
+		if ($result = $this->_db->loadAssoc()) 
 		{
 			return $this->bind($result);
-		}
-		else
+		} 
+		else 
 		{
 			$this->setError($this->_db->getErrorMsg());
 			return false;
@@ -180,10 +188,12 @@ class ResourcesSponsor extends JTable
 	}
 
 	/**
-	 * Get record count
-	 *
-	 * @param      array $filters Filters to apply to query
-	 * @return     integer
+	 * Short description for 'getAllCount'
+	 * 
+	 * Long description (if any) ...
+	 * 
+	 * @param      array $filters Parameter description (if any) ...
+	 * @return     object Return description (if any) ...
 	 */
 	public function getCount($filters=array())
 	{
@@ -198,22 +208,24 @@ class ResourcesSponsor extends JTable
 	}
 
 	/**
-	 * Get a list of records
-	 *
-	 * @param      array $filters Filters to apply to query
-	 * @return     array
+	 * Short description for 'getAllTypes'
+	 * 
+	 * Long description (if any) ...
+	 * 
+	 * @param      array $filters Parameter description (if any) ...
+	 * @return     object Return description (if any) ...
 	 */
 	public function getRecords($filters=array())
 	{
-		if (!isset($filters['sort']) || !$filters['sort'])
+		if (!isset($filters['sort']) || !$filters['sort']) 
 		{
 			$filters['sort'] = 'title';
 		}
-		if (!isset($filters['sort_Dir']) || !$filters['sort_Dir'])
+		if (!isset($filters['sort_Dir']) || !$filters['sort_Dir']) 
 		{
 			$filters['sort_Dir'] = 'ASC';
 		}
-
+		
 		$query  = "SELECT * FROM $this->_tbl";
 		if (isset($filters['state']))
 		{
